@@ -17,7 +17,7 @@ use Scalar::Util 'weaken', 'isweak';
 use Try::Tiny;
 use URI;
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 our @CARP_NOT;
 
 =head1 NAME
@@ -911,7 +911,7 @@ use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 has 'protocol' => (
     is => 'ro',
@@ -967,9 +967,8 @@ The public support forum of this module is L<https://perlmonks.org/>.
 
 =head1 BUG TRACKER
 
-Please report bugs in this module via the RT CPAN bug queue at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=WWW-Mechanize-Chrome>
-or via mail to L<www-mechanize-Chrome-Bugs@rt.cpan.org|mailto:www-mechanize-Chrome-Bugs@rt.cpan.org>.
+Please report bugs in this module via the Github bug queue at
+L<https://github.com/Corion/WWW-Mechanize-Chrome/issues>
 
 =head1 AUTHOR
 
@@ -977,7 +976,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2010-2020 by Max Maischein C<corion@cpan.org>.
+Copyright 2010-2021 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
